@@ -227,16 +227,10 @@ public class Launcher {
         //First checks whether offline-allowed tag is specified inside the jnlp
         //file.
         if (!file.getInformation().isOfflineAllowed()) {
-            try {
-                //Checks the offline/online status of the system.
-                //If system is offline do not launch.
-                InetAddress.getByName(file.getSourceLocation().getHost());
-
-            } catch (UnknownHostException ue) {
+            //offline status should be already known from jnlp downloading
+            if (!JNLPRuntime.isOnlineDetected()) {
                 OutputController.getLogger().log(OutputController.Level.ERROR_ALL, "File cannot be launched because offline-allowed tag not specified and system currently offline.");
                 return null;
-            } catch (Exception e) {
-                OutputController.getLogger().log(e);
             }
         }
 
@@ -321,18 +315,12 @@ public class Launcher {
      */
     private void addProperties(JNLPFile file, String[] props) throws LaunchException {
         ResourcesDesc resources = file.getResources();
-
-        for (int i = 0; i < props.length; i++) {
-            // allows empty property, not sure about validity of that.
-            int equals = props[i].indexOf("=");
-            if (equals == -1) {
-                throw launchError(new LaunchException(R("BBadProp", props[i])));
+        for (String prop : props) {
+            try{
+                resources.addResource(PropertyDesc.fromString(prop, R("BBadProp", prop)));
+            }catch (LaunchException ex){
+                throw launchError(ex);
             }
-
-            String key = props[i].substring(0, equals);
-            String value = props[i].substring(equals + 1, props[i].length());
-
-            resources.addResource(new PropertyDesc(key, value));
         }
     }
 
@@ -479,7 +467,12 @@ public class Launcher {
             }
 
             if (isLocal && haveHref) {
-                file = new JNLPFile(file.getSourceLocation(), parserSettings);
+                JNLPFile fileFromHref = new JNLPFile(file.getSourceLocation(), parserSettings);
+                if (fileFromHref.getCodeBase() == null) {
+                    fileFromHref.codeBase = file.getCodeBase();
+                }
+                file = fileFromHref;
+
             }
             return file;
         } catch (Exception ex) {
