@@ -25,9 +25,11 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.net.HttpURLConnection;
+import java.net.InetAddress;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLConnection;
+import java.net.UnknownHostException;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
 import java.util.ArrayList;
@@ -393,8 +395,18 @@ public class ResourceTracker {
 
             if (location.getProtocol().equalsIgnoreCase("file")) {
                 File file = UrlUtils.decodeUrlAsFile(location);
-                if (file.exists())
+                if (file.exists()) {
                     return file;
+                }
+                // try plain, not decoded file now
+                // sometimes the jnlp app developers are encoding for us
+                // so we end up encoding already encoded file. See RH1154177
+                file = new File(location.getPath());
+                if (file.exists()) {
+                    return file;
+                }
+                // have it sense to try also filename with whole query here?
+                // => location.getFile() ?
             }
 
             return null;
@@ -404,33 +416,7 @@ public class ResourceTracker {
         }
     }
 
-    /**
-     * Returns an input stream that reads the contents of the
-     * resource.  For non-cacheable resources, an InputStream that
-     * reads from the source location is returned.  Otherwise the
-     * InputStream reads the cached resource.
-     * <p>
-     * This method will block while the resource is downloaded to
-     * the cache.
-     * </p>
-     *
-     * @throws IOException if there was an error opening the stream
-     * @throws IllegalResourceDescriptorException if the resource is not being tracked
-     */
-    public InputStream getInputStream(URL location) throws IOException {
-        try {
-            Resource resource = getResource(location);
-            if (!resource.isSet(DOWNLOADED | ERROR))
-                waitForResource(location, 0);
 
-            if (resource.localFile != null)
-                return new FileInputStream(resource.localFile);
-
-            return resource.location.openStream();
-        } catch (InterruptedException ex) {
-            throw new IOException("wait was interrupted");
-        }
-    }
 
     /**
      * Wait for a group of resources to be downloaded and made
@@ -776,6 +762,10 @@ public class ResourceTracker {
      * fields.
      */
     private void initializeResource(Resource resource) {
+        //verify connection
+        if(!JNLPRuntime.isOfflineForced()){
+            JNLPRuntime.detectOnline(resource.getLocation()/*or doenloadLocation*/);
+        }
         resource.fireDownloadEvent(); // fire CONNECTING
 
         CacheEntry entry = new CacheEntry(resource.location, resource.requestVersion);
@@ -783,31 +773,41 @@ public class ResourceTracker {
 
         try {
             File localFile = CacheUtil.getCacheFile(resource.location, resource.downloadVersion);
-
-            // connect
-            URL finalLocation = findBestUrl(resource);
-
-            if (finalLocation == null) {
-                OutputController.getLogger().log(OutputController.Level.ERROR_ALL, "Attempted to download " + resource.location + ", but failed to connect!");
-                throw new NullPointerException("finalLocation == null"); // Caught below
+            long size = 0;
+            boolean current = true;
+            //this can be null, as it is always filled in online mode, and never read in offline mode
+            URLConnection connection = null;
+            if (localFile != null) {
+                size = localFile.length();
+            } else if (!JNLPRuntime.isOnline()) {
+                OutputController.getLogger().log(OutputController.Level.ERROR_ALL, "You are trying to get resource " + resource.getLocation().toExternalForm() + " but you are in offline mode, and it is not in cache. Attempting to continue, but you may expect failure");
             }
+            if (JNLPRuntime.isOnline()) {
+                // connect
+                URL finalLocation = findBestUrl(resource);
 
-            resource.setDownloadLocation(finalLocation);
-            URLConnection connection = finalLocation.openConnection(); // this won't change so should be okay unsynchronized
-            connection.addRequestProperty("Accept-Encoding", "pack200-gzip, gzip");
+                if (finalLocation == null) {
+                    OutputController.getLogger().log(OutputController.Level.ERROR_ALL, "Attempted to download " + resource.location + ", but failed to connect!");
+                    throw new NullPointerException("finalLocation == null"); // Caught below
+                }
 
-            int size = connection.getContentLength();
-            boolean current = CacheUtil.isCurrent(resource.location, resource.requestVersion, connection) && resource.getUpdatePolicy() != UpdatePolicy.FORCE;
-            if (!current) {
-                if (entry.isCached()) {
-                    entry.markForDelete();
-                    entry.store();
-                    // Old entry will still exist. (but removed at cleanup)
-                    localFile = CacheUtil.makeNewCacheFile(resource.location, resource.downloadVersion);
-                    CacheEntry newEntry = new CacheEntry(resource.location, resource.requestVersion);
-                    newEntry.lock();
-                    entry.unlock();
-                    entry = newEntry;
+                resource.setDownloadLocation(finalLocation);
+                connection = finalLocation.openConnection(); // this won't change so should be okay unsynchronized
+                connection.addRequestProperty("Accept-Encoding", "pack200-gzip, gzip");
+
+                size = connection.getContentLength();
+                current = CacheUtil.isCurrent(resource.location, resource.requestVersion, connection) && resource.getUpdatePolicy() != UpdatePolicy.FORCE;
+                if (!current) {
+                    if (entry.isCached()) {
+                        entry.markForDelete();
+                        entry.store();
+                        // Old entry will still exist. (but removed at cleanup)
+                        localFile = CacheUtil.makeNewCacheFile(resource.location, resource.downloadVersion);
+                        CacheEntry newEntry = new CacheEntry(resource.location, resource.requestVersion);
+                        newEntry.lock();
+                        entry.unlock();
+                        entry = newEntry;
+                    }
                 }
             }
 
@@ -823,7 +823,7 @@ public class ResourceTracker {
             }
 
             // update cache entry
-            if (!current)
+            if (!current && JNLPRuntime.isOnline())
                 entry.initialize(connection);
 
             entry.setLastUpdated(System.currentTimeMillis());
