@@ -38,9 +38,14 @@ exception statement from your version. */
 package net.sourceforge.jnlp.cache;
 
 import java.net.MalformedURLException;
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.net.URL;
+import java.net.URLDecoder;
+import java.net.URLEncoder;
 import java.util.LinkedList;
 import java.util.List;
+import java.io.UnsupportedEncodingException;
 
 import net.sourceforge.jnlp.DownloadOptions;
 
@@ -89,7 +94,7 @@ public class ResourceUrlCreator {
             }
         }
 
-        url = getVersionedUrlUsingQuery(resource);
+        url = getVersionedUrl();
         urls.add(url);
 
         urls.add(resource.getLocation());
@@ -146,29 +151,47 @@ public class ResourceUrlCreator {
     }
 
     /**
-     * Returns the URL for a resource, relying on HTTP query for getting the
-     * right version
-     *
-     * @param resource the resource to get the url for
+     * Returns the URL for this resource, including the resource's version number in the query string
      */
-    protected URL getVersionedUrlUsingQuery(Resource resource) {
-        String actualLocation = resource.getLocation().getProtocol() + "://"
-                + resource.getLocation().getHost();
-        if (resource.getLocation().getPort() != -1) {
-            actualLocation += ":" + resource.getLocation().getPort();
+    protected URL getVersionedUrl() {
+        URL resourceUrl = resource.getLocation();
+        String protocol = uriPartToString(resourceUrl.getProtocol()) + "://";
+        String userInfo = uriPartToString(resourceUrl.getUserInfo());
+        if (!userInfo.isEmpty()) {
+            userInfo += "@";
         }
-        actualLocation += resource.getLocation().getPath();
-        if (resource.requestVersion != null
-                && resource.requestVersion.isVersionId()) {
-            actualLocation += "?version-id=" + resource.requestVersion;
+        String host = uriPartToString(resourceUrl.getHost());
+        String port;
+        if (resourceUrl.getPort() == -1) {
+            port = "";
+        } else {
+            port = ":" + String.valueOf(resourceUrl.getPort());
+        }
+        String path = uriPartToString(resourceUrl.getPath());
+        String query = uriPartToString(resourceUrl.getQuery());
+        if (!query.isEmpty()) {
+            query = "?" + query;
+        }
+        if (resource.requestVersion != null && resource.requestVersion.isVersionId()) {
+            if (!query.isEmpty()) {
+                query += "&";
+            } else {
+                query = "?" + query;
+            }
+            query += "version-id=" + resource.requestVersion;
         }
-        URL versionedURL;
         try {
-            versionedURL = new URL(actualLocation);
+            URL url = new URL(protocol + userInfo + host + port + path + query);
+            return url;
         } catch (MalformedURLException e) {
-            return resource.getLocation();
+            return resourceUrl;
         }
-        return versionedURL;
     }
 
-}
\ No newline at end of file
+    private static String uriPartToString(String part) {
+        if (part == null)
+            return "";
+        return part;
+    }
+
+}
