@@ -38,13 +38,14 @@ import net.sourceforge.jnlp.event.ApplicationEvent;
 import net.sourceforge.jnlp.event.ApplicationListener;
 import net.sourceforge.jnlp.security.SecurityDialogs;
 import net.sourceforge.jnlp.security.SecurityDialogs.AccessType;
+import net.sourceforge.jnlp.util.logging.OutputController;
 import net.sourceforge.jnlp.util.WeakList;
 import net.sourceforge.jnlp.util.XDesktopEntry;
 
 /**
  * Represents a running instance of an application described in a
- * JNLPFile.  This class provides a way to track the application's
- * resources and destroy the application.<p>
+ * JNLPFile. This class provides a way to track the application's
+ * resources and destroy the application.
  *
  * @author <a href="mailto:jmaxwell@users.sourceforge.net">Jon A. Maxwell (JAM)</a> - initial author
  * @version $Revision: 1.15 $
@@ -64,12 +65,15 @@ public class ApplicationInstance {
     private ClassLoader loader;
 
     /**
+     * <p>
      * Every application/applet gets its own AppContext. This allows us to do
      * things like have two different look and feels for two different applets
      * (running in the same VM), allows untrusted programs to manipulate the
-     * event queue (safely) and (possibly) more.<p>
-     *
+     * event queue (safely) and (possibly) more.
+     * </p>
+     * <p>
      * It is set to the AppContext which created this ApplicationInstance
+     * </p>
      */
     private AppContext appContext;
 
@@ -149,10 +153,8 @@ public class ApplicationInstance {
         ShortcutDesc sd = file.getInformation().getShortcut();
         File possibleDesktopFile = entry.getLinuxDesktopIconFile();
         if (possibleDesktopFile.exists()) {
-            if (JNLPRuntime.isDebug()) {
-                System.out.println("ApplicationInstance.addMenuAndDesktopEntries(): file - "
-                        + possibleDesktopFile.getAbsolutePath() + " already exists. Not proceeding with desktop additions");
-            }
+            OutputController.getLogger().log("ApplicationInstance.addMenuAndDesktopEntries(): file - "
+                    + possibleDesktopFile.getAbsolutePath() + " already exists. Not proceeding with desktop additions");
             return;
         }
         if (shouldCreateShortcut(sd)) {
@@ -163,10 +165,8 @@ public class ApplicationInstance {
             /*
              * Sun's WebStart implementation doesnt seem to do anything under GNOME
              */
-            if (JNLPRuntime.isDebug()) {
-                System.err.println("ApplicationInstance.addMenuAndDesktopEntries():"
-                        + " Adding menu entries NOT IMPLEMENTED");
-            }
+            OutputController.getLogger().log(OutputController.Level.ERROR_DEBUG, "ApplicationInstance.addMenuAndDesktopEntries():"
+                    + " Adding menu entries NOT IMPLEMENTED");
         }
 
     }
@@ -218,7 +218,7 @@ public class ApplicationInstance {
      * Only collectable if classloader and thread group are
      * also collectable so basically is almost never called (an
      * application would have to close its windows and exit its
-     * threads but not call System.exit).
+     * threads but not call JNLPRuntime.exit).
      */
     public void finalize() {
         destroy();
@@ -294,9 +294,7 @@ public class ApplicationInstance {
             Thread threads[] = new Thread[group.activeCount() * 2];
             int nthreads = group.enumerate(threads);
             for (int i = 0; i < nthreads; i++) {
-                if (JNLPRuntime.isDebug())
-                    System.out.println("Interrupt thread: " + threads[i]);
-
+                OutputController.getLogger().log("Interrupt thread: " + threads[i]);
                 threads[i].interrupt();
             }
 
@@ -304,9 +302,7 @@ public class ApplicationInstance {
             Thread.yield();
             nthreads = group.enumerate(threads);
             for (int i = 0; i < nthreads; i++) {
-                if (JNLPRuntime.isDebug())
-                    System.out.println("Stop thread: " + threads[i]);
-
+                OutputController.getLogger().log("Stop thread: " + threads[i]);
                 threads[i].stop();
             }
 
