@@ -33,6 +33,7 @@ import java.util.List;
 import java.util.StringTokenizer;
 
 import net.sourceforge.jnlp.config.DeploymentConfiguration;
+import net.sourceforge.jnlp.util.logging.OutputController;
 
 /**
  * A ProxySelector specific to JNLPs. This proxy uses the deployment
@@ -82,19 +83,14 @@ public abstract class JNLPProxySelector extends ProxySelector {
     // FIXME what is this? where should it be used?
     private String overrideHosts = null;
 
-    /**
-     * Creates a new JNLPProxySelector.
-     */
-    public JNLPProxySelector() {
-        parseConfiguration();
+    public JNLPProxySelector(DeploymentConfiguration config) {
+        parseConfiguration(config);
     }
 
     /**
      * Initialize this ProxySelector by reading the configuration
      */
-    private void parseConfiguration() {
-        DeploymentConfiguration config = JNLPRuntime.getConfiguration();
-
+    private void parseConfiguration(DeploymentConfiguration config) {
         proxyType = Integer.valueOf(config.getProperty(DeploymentConfiguration.KEY_PROXY_TYPE));
 
         String autoConfigString = config.getProperty(DeploymentConfiguration.KEY_PROXY_AUTO_CONFIG_URL);
@@ -102,7 +98,7 @@ public abstract class JNLPProxySelector extends ProxySelector {
             try {
                 autoConfigUrl = new URL(autoConfigString);
             } catch (MalformedURLException e) {
-                e.printStackTrace();
+                OutputController.getLogger().log(OutputController.Level.ERROR_ALL, e);
             }
         }
 
@@ -164,7 +160,7 @@ public abstract class JNLPProxySelector extends ProxySelector {
             try {
                 proxyPort = Integer.valueOf(port);
             } catch (NumberFormatException e) {
-                e.printStackTrace();
+                OutputController.getLogger().log(OutputController.Level.ERROR_ALL, e);
             }
         }
         return proxyPort;
@@ -175,7 +171,7 @@ public abstract class JNLPProxySelector extends ProxySelector {
      */
     @Override
     public void connectFailed(URI uri, SocketAddress sa, IOException ioe) {
-        ioe.printStackTrace();
+        OutputController.getLogger().log(OutputController.Level.ERROR_ALL, ioe);
     }
 
     /**
@@ -183,15 +179,11 @@ public abstract class JNLPProxySelector extends ProxySelector {
      */
     @Override
     public List<Proxy> select(URI uri) {
-        if (JNLPRuntime.isDebug()) {
-            System.out.println("Selecting proxy for: " + uri);
-        }
-
+        OutputController.getLogger().log("Selecting proxy for: " + uri);
+        
         if (inBypassList(uri)) {
             List<Proxy> proxies = Arrays.asList(new Proxy[] { Proxy.NO_PROXY });
-            if (JNLPRuntime.isDebug()) {
-                System.out.println("Selected proxies: " + Arrays.toString(proxies.toArray()));
-            }
+            OutputController.getLogger().log("Selected proxies: " + Arrays.toString(proxies.toArray()));
             return proxies;
         }
 
@@ -216,9 +208,7 @@ public abstract class JNLPProxySelector extends ProxySelector {
                 break;
         }
 
-        if (JNLPRuntime.isDebug()) {
-            System.out.println("Selected proxies: " + Arrays.toString(proxies.toArray()));
-        }
+        OutputController.getLogger().log("Selected proxies: " + Arrays.toString(proxies.toArray()));
         return proxies;
     }
 
@@ -240,7 +230,7 @@ public abstract class JNLPProxySelector extends ProxySelector {
                     return true;
                 }
             } else if (scheme.equals("socket")) {
-                String host = uri.getSchemeSpecificPart().split(":")[0];
+                String host = uri.getHost();
 
                 if (bypassLocal && isLocalHost(host)) {
                     return true;
@@ -298,32 +288,61 @@ public abstract class JNLPProxySelector extends ProxySelector {
      * @return a List of Proxy objects
      */
     private List<Proxy> getFromConfiguration(URI uri) {
+        return getFromArguments(uri, sameProxy, false,
+                proxyHttpsHost, proxyHttpsPort,
+                proxyHttpHost, proxyHttpPort,
+                proxyFtpHost, proxyFtpPort,
+                proxySocks4Host, proxySocks4Port);
+    }
+
+    /**
+     * Returns a list of proxies by using the arguments
+     *
+     * @return a List of Proxy objects
+     */
+    protected static List<Proxy> getFromArguments(URI uri,
+            boolean sameProxy, boolean sameProxyIncludesSocket,
+            String proxyHttpsHost, int proxyHttpsPort,
+            String proxyHttpHost, int proxyHttpPort,
+            String proxyFtpHost, int proxyFtpPort,
+            String proxySocks4Host, int proxySocks4Port) {
+
         List<Proxy> proxies = new ArrayList<Proxy>();
 
         String scheme = uri.getScheme();
 
+        boolean socksProxyAdded = false;
+
         if (sameProxy) {
-            SocketAddress sa = new InetSocketAddress(proxyHttpHost, proxyHttpPort);
-            Proxy proxy;
-            if (scheme.equals("socket")) {
-                proxy = new Proxy(Type.SOCKS, sa);
-            } else {
-                proxy = new Proxy(Type.HTTP, sa);
+            if (proxyHttpHost != null) {
+                SocketAddress sa = new InetSocketAddress(proxyHttpHost, proxyHttpPort);
+                if ((scheme.equals("https") || scheme.equals("http") || scheme.equals("ftp"))) {
+                    Proxy proxy = new Proxy(Type.HTTP, sa);
+                    proxies.add(proxy);
+                } else if (scheme.equals("socket") && sameProxyIncludesSocket) {
+                    Proxy proxy = new Proxy(Type.SOCKS, sa);
+                    proxies.add(proxy);
+                    socksProxyAdded = true;
+                }
             }
-            proxies.add(proxy);
-        } else if (scheme.equals("http")) {
+        } else if (scheme.equals("http") && proxyHttpHost != null) {
             SocketAddress sa = new InetSocketAddress(proxyHttpHost, proxyHttpPort);
             proxies.add(new Proxy(Type.HTTP, sa));
-        } else if (scheme.equals("https")) {
+        } else if (scheme.equals("https") && proxyHttpsHost != null) {
             SocketAddress sa = new InetSocketAddress(proxyHttpsHost, proxyHttpsPort);
             proxies.add(new Proxy(Type.HTTP, sa));
-        } else if (scheme.equals("ftp")) {
+        } else if (scheme.equals("ftp") && proxyFtpHost != null) {
             SocketAddress sa = new InetSocketAddress(proxyFtpHost, proxyFtpPort);
             proxies.add(new Proxy(Type.HTTP, sa));
-        } else if (scheme.equals("socket")) {
+        }
+
+        if (!socksProxyAdded && (proxySocks4Host != null)) {
             SocketAddress sa = new InetSocketAddress(proxySocks4Host, proxySocks4Port);
             proxies.add(new Proxy(Type.SOCKS, sa));
-        } else {
+            socksProxyAdded = true;
+        }
+
+        if (proxies.size() == 0) {
             proxies.add(Proxy.NO_PROXY);
         }
 
@@ -348,7 +367,7 @@ public abstract class JNLPProxySelector extends ProxySelector {
             String proxiesString = pacEvaluator.getProxies(uri.toURL());
             proxies.addAll(getProxiesFromPacResult(proxiesString));
         } catch (MalformedURLException e) {
-            e.printStackTrace();
+            OutputController.getLogger().log(OutputController.Level.ERROR_ALL, e);
             proxies.add(Proxy.NO_PROXY);
         }
 
@@ -368,7 +387,8 @@ public abstract class JNLPProxySelector extends ProxySelector {
      * suitable for java.
      * @param pacString a string indicating proxies. For example
      * "PROXY foo.bar:3128; DIRECT"
-     * @return a list of Proxy objects represeting the parsed string.
+     * @return a list of Proxy objects representing the parsed string. In
+     * case of malformed input, an empty list may be returned
      */
     public static List<Proxy> getProxiesFromPacResult(String pacString) {
         List<Proxy> proxies = new ArrayList<Proxy>();
@@ -406,9 +426,7 @@ public abstract class JNLPProxySelector extends ProxySelector {
             } else if (token.startsWith("DIRECT")) {
                 proxies.add(Proxy.NO_PROXY);
             } else {
-                if (JNLPRuntime.isDebug()) {
-                    System.out.println("Unrecognized proxy token: " + token);
-                }
+                 OutputController.getLogger().log("Unrecognized proxy token: " + token);
             }
         }
 
