@@ -37,7 +37,6 @@ exception statement from your version.
 
 package net.sourceforge.jnlp.runtime;
 
-import java.io.IOException;
 import java.io.InputStream;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
@@ -60,12 +59,14 @@ public class PacEvaluatorFactory {
         try {
             properties = new Properties();
             properties.load(in);
-        } catch (IOException e) {
+        } catch (Exception e) {
+            OutputController.getLogger().log(OutputController.Level.WARNING_ALL, "PAC provider is broken or don't exists. This is ok unless your application is using JavaScript.");
             OutputController.getLogger().log(e);
         } finally {
             try {
                 in.close();
-            } catch (IOException e) {
+            } catch (Exception e) {
+                OutputController.getLogger().log(OutputController.Level.WARNING_ALL, "PAC provider is broken or don't exists. This is ok unless your application is using JavaScript.");
                 OutputController.getLogger().log(e);
             }
         }
