@@ -54,11 +54,11 @@ public class UnsignedAppletActionEntry {
         UnsignedAppletActionEntry nw = new UnsignedAppletActionEntry(
                 ExecuteAppletAction.fromString(split[0]),
                 new Date(new Long(split[1])),
-                new UrlRegEx(split[2]),
+                UrlRegEx.exact(split[2]),
                 null,
                 null);
         if (split.length > 3) {
-            nw.setCodeBase(new UrlRegEx(split[3]));
+            nw.setCodeBase(UrlRegEx.exact(split[3]));
         }
         if (split.length > 4) {
             nw.setArchives(createArchivesList(s.substring(s.lastIndexOf(split[3]) + split[3].length()).trim()));
@@ -85,12 +85,16 @@ public class UnsignedAppletActionEntry {
         bw.write(this.serializeToReadableAndParseableString());
     }
 
-    private String serializeToReadableAndParseableString() {
-        return unsignedAppletAction.toChar()
+    private String serializeToReadableAndParseableString() throws InvalidLineException {
+        String s = unsignedAppletAction.toChar()
                 + " " + ((timeStamp == null) ? "1" : timeStamp.getTime())
                 + " " + ((documentBase == null) ? "" : documentBase.getRegEx())
                 + " " + ((codeBase == null) ? "" : codeBase.getRegEx())
                 + " " + createArchivesString(archives);
+        if (s.contains("\n") || s.contains("\r") || s.contains("\f")){
+            throw new InvalidLineException("Cant write line with \\n, \\r or \\f");
+        }
+        return s;
     }
 
     public Date getTimeStamp() {
