@@ -480,6 +480,14 @@ public class PolicyEditor extends JPanel {
             if (editor.changesMade) {
                 final int save = JOptionPane.showConfirmDialog(this, R("PESaveChanges"));
                 if (save == JOptionPane.YES_OPTION) {
+                    if (editor.file == null) {
+                        final int choice = editor.fileChooser.showSaveDialog(this);
+                        if (choice == JFileChooser.APPROVE_OPTION) {
+                            editor.file = editor.fileChooser.getSelectedFile();
+                        } else if (choice == JFileChooser.CANCEL_OPTION) {
+                            return;
+                        }
+                    }
                     editor.savePolicyFile();
                 } else if (save == JOptionPane.CANCEL_OPTION) {
                     return;
@@ -545,6 +553,14 @@ public class PolicyEditor extends JPanel {
             if (editor.changesMade) {
                 final int save = JOptionPane.showConfirmDialog(this, R("PESaveChanges"));
                 if (save == JOptionPane.YES_OPTION) {
+                    if (editor.file == null) {
+                        final int choice = editor.fileChooser.showSaveDialog(this);
+                        if (choice == JFileChooser.APPROVE_OPTION) {
+                            editor.file = editor.fileChooser.getSelectedFile();
+                        } else if (choice == JFileChooser.CANCEL_OPTION) {
+                            return;
+                        }
+                    }
                     editor.savePolicyFile();
                 } else if (save == JOptionPane.CANCEL_OPTION) {
                     return;
@@ -1310,27 +1326,29 @@ public class PolicyEditor extends JPanel {
                 sb.append("\n/* Generated by PolicyEditor at ").append(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss")
                               .format(Calendar.getInstance().getTime())).append(" */").append(System.getProperty("line.separator"));
                 final Set<PolicyEditorPermissions> enabledPermissions = new HashSet<PolicyEditorPermissions>();
-                FileLock fileLock;
+                FileLock fileLock = null;
                 try {
                     fileLock = FileUtils.getFileLock(file.getAbsolutePath(), false, true);
-                } catch (final FileNotFoundException e) {
-                    OutputController.getLogger().log(e);
-                    showCouldNotSaveDialog();
-                    return;
-                }
-                for (final String codebase : codebasePermissionsMap.keySet()) {
-                    enabledPermissions.clear();
-                    for (final Map.Entry<PolicyEditorPermissions, Boolean> entry : codebasePermissionsMap.get(codebase).entrySet()) {
-                        if (entry.getValue()) {
-                            enabledPermissions.add(entry.getKey());
+                    for (final String codebase : codebasePermissionsMap.keySet()) {
+                        enabledPermissions.clear();
+                        for (final Map.Entry<PolicyEditorPermissions, Boolean> entry : codebasePermissionsMap.get(codebase).entrySet()) {
+                            if (entry.getValue()) {
+                                enabledPermissions.add(entry.getKey());
+                            }
                         }
+                        sb.append(new PolicyEntry(codebase, enabledPermissions, customPermissionsMap.get(codebase)).toString());
                     }
-                    sb.append(new PolicyEntry(codebase, enabledPermissions, customPermissionsMap.get(codebase)).toString());
-                }
-                try {
-                    fileLock.release();
+
                 } catch (final IOException e) {
                     OutputController.getLogger().log(e);
+                } finally {
+                    if (fileLock != null) {
+                        try {
+                            fileLock.release();
+                        } catch (final IOException e) {
+                            OutputController.getLogger().log(e);
+                        }
+                    }
                 }
 
                 try {
