@@ -205,6 +205,8 @@ public class ConsoleOutputPaneModel {
             }
             String line = (createLine(messageWithHeader));
             if (mark) {
+                line = line.replaceAll("<", "&lt;");
+                line = line.replaceAll(">", "&gt;");
                 line = line.replaceAll("\n", "<br/>\n");
                 line = line.replaceAll("  ", "&nbsp; ");//small trick, html is reducting row of spaces to single space. This handles it and stimm allow line wrap
                 line = line.replaceAll("\t", "&nbsp;&nbsp;&nbsp;&nbsp;");
@@ -288,7 +290,7 @@ public class ConsoleOutputPaneModel {
                     Collections.sort(sortedData, new CatchedMessageWithHeaderComparator() {
                         @Override
                         public int body(MessageWithHeader o1, MessageWithHeader o2) {
-                            return o1.getHeader().date.compareTo(o2.getHeader().date);
+                            return o1.getHeader().timestamp.compareTo(o2.getHeader().timestamp);
                         }
                     });
                     break;
