@@ -83,7 +83,7 @@ import net.sourceforge.jnlp.util.logging.OutputController;
  * {@link #createAnotherElement() createAnotherElement}
  * which has to return a new copy of the receiver.
  * </dd></dl>
- * </p>
+ *
  *
  * @see net.sourceforge.nanoxml.XMLParseException
  *
@@ -178,7 +178,7 @@ public class XMLElement {
     private boolean ignoreWhitespace;
 
     /**
-     * Character read too much.<br/>
+     * Character read too much.<br>
      * This character provides push-back functionality to the input reader
      * without having to use a PushbackReader.
      * If there is no such character, this field is {@code '\0'}.
@@ -210,7 +210,7 @@ public class XMLElement {
     private int parserLineNr;
 
     /**
-     * Creates and initializes a new XML element.<br/>
+     * Creates and initializes a new XML element.<br>
      * Calling the construction is equivalent to:
      * <ul><li>{@code new XMLElement(new Hashtable(), false, true)}</li></ul>
      *
@@ -400,7 +400,7 @@ public class XMLElement {
     }
 
     /**
-     * Returns an attribute of the element.<br/>
+     * Returns an attribute of the element.<br>
      * If the attribute doesn't exist, {@code null} is returned.
      *
      * @param name The name of the attribute.
@@ -535,7 +535,7 @@ public class XMLElement {
      *     The new name.
      *
      * <dl><dt><b>Preconditions:</b></dt><dd>
-     * <ul><li{@code name != null}</li>
+     * <ul><li>{@code name != null}</li>
      *     <li>{@code name} is a valid XML identifier</li>
      * </ul></dd></dl>
      */
@@ -597,7 +597,7 @@ public class XMLElement {
     }
 
     /**
-     * This method scans an identifier from the current reader.<br/>
+     * This method scans an identifier from the current reader.<br>
      * The scanned whitespace is appended to {@code result}.
      *
      * @return the next character following the whitespace.
@@ -625,7 +625,7 @@ public class XMLElement {
     }
 
     /**
-     * This method scans a delimited string from the current reader.<br/>
+     * This method scans a delimited string from the current reader.<br>
      * The scanned string without delimiters is appended to {@code string}.
      *
      * <dl><dt><b>Preconditions:</b></dt><dd>
@@ -653,8 +653,8 @@ public class XMLElement {
 
     /**
      * Scans a {@code #PCDATA} element. CDATA sections and entities are
-     * resolved.<br/>
-     * The next &lt; char is skipped.<br/>
+     * resolved.<br>
+     * The next &lt; char is skipped.<br>
      * The scanned data is appended to {@code data}.
      *
      * <dl><dt><b>Preconditions:</b></dt><dd>
@@ -831,7 +831,7 @@ public class XMLElement {
     }
 
     /**
-     * Scans the data for literal text.<br/>
+     * Scans the data for literal text.<br>
      * Scanning stops when a character does not match or after the complete
      * text has been checked, whichever comes first.
      *
@@ -985,7 +985,7 @@ public class XMLElement {
     }
 
     /**
-     * Resolves an entity. The name of the entity is read from the reader.<br/>
+     * Resolves an entity. The name of the entity is read from the reader.<br>
      * The value of the entity is appended to {@code buf}.
      *
      * @param buf Where to put the entity value.
@@ -1157,9 +1157,9 @@ public class XMLElement {
      *             filtered xml file.
      */
     public void sanitizeInput(Reader isr, OutputStream pout) {
+        StringBuilder line = new StringBuilder();
         try {
             PrintStream out = new PrintStream(pout);
-
             this.sanitizeCharReadTooMuch = '\0';
             this.reader = isr;
             this.parserLineNr = 0;
@@ -1192,14 +1192,12 @@ public class XMLElement {
                     // what's in the buffer
                     out.print(ch);
                     out.flush();
-                    if (JNLPRuntime.isDebug()) {
-                        if (ch == 10) {
-                            OutputController.getLogger().printOutLn("");
-                            OutputController.getLogger().printOut("line: " + newline + " ");
-                            newline++;
-                        } else {
-                            OutputController.getLogger().printOut(ch+"");
-                        }
+                    if (ch == 10) {
+                        OutputController.getLogger().log(line.toString());
+                        line = new StringBuilder("line: " + newline + " ");
+                        newline++;
+                    } else {
+                        line.append(ch);
                     }
                     break;
                 } else if (i == 10) {
@@ -1224,44 +1222,41 @@ public class XMLElement {
                             out.print('!');
                             out.print('-');
                             this.sanitizeCharReadTooMuch = ch;
-                            if (JNLPRuntime.isDebug()) {
-                                OutputController.getLogger().printOut("<");
-                                OutputController.getLogger().printOut("!");
-                                OutputController.getLogger().printOut("-");
-                            }
+                            line.append("<");
+                            line.append("!");
+                            line.append("-");
                         }
                     } else {
                         out.print('<');
                         out.print('!');
                         this.sanitizeCharReadTooMuch = ch;
-                        if (JNLPRuntime.isDebug()) {
-                              OutputController.getLogger().printOut("<");
-                              OutputController.getLogger().printOut("!");
-                        }
+                        line.append("<");
+                        line.append("!");
                     }
                 }
                 // Otherwise we haven't hit a comment, and we should write ch.
                 else {
                     out.print(ch);
-                    if (JNLPRuntime.isDebug()) {
-                        if (ch == 10) {
-                            OutputController.getLogger().printOutLn("");
-                            OutputController.getLogger().printOut("line: " + newline + " ");
-                            newline++;
-                        } else {
-                            OutputController.getLogger().printOut(ch+"");
-                        }
+                    if (ch == 10) {
+                        OutputController.getLogger().log(line.toString());
+                        line = new StringBuilder("line: " + newline + " ");
+                        newline++;
+                    } else {
+                        line.append(ch);
                     }
                 }
                 prev = next;
             }
-
             out.close();
             isr.close();
         } catch (Exception e) {
             // Print the stack trace here -- xml.parseFromReader() will
             // throw the ParseException if something goes wrong.
             OutputController.getLogger().log(OutputController.Level.ERROR_ALL, e);
+        } finally {
+            OutputController.getLogger().log("");//force new line in all cases
+            OutputController.getLogger().log(line.toString()); //flush remaining line
+
         }
     }
 }
