@@ -239,8 +239,6 @@ std::string plugin_file_log_name;
 int plugin_debug_suspend = (getenv("ICEDTEAPLUGIN_DEBUG") != NULL) &&
         (strcmp(getenv("ICEDTEAPLUGIN_DEBUG"), "suspend") == 0);
 
-pthread_cond_t cond_message_available = PTHREAD_COND_INITIALIZER;
-
 
 #ifdef LEGACY_GLIB
 // Returns key from first item stored in hashtable
@@ -375,6 +373,10 @@ ITNP_New (NPMIMEType pluginType, NPP instance, uint16_t mode,
 
   // start the jvm if needed
    NPError startup_error = start_jvm_if_needed();
+   if (startup_error != NPERR_NO_ERROR) {
+	   PLUGIN_ERROR ("Failed to start JVM\n");
+	   return startup_error;
+   }
 
   // Initialize data->instance_id.
   //
@@ -2027,7 +2029,7 @@ NP_Initialize (NPNetscapeFuncs* browserTable, NPPluginFuncs* pluginTable)
   NPError np_error =  initialize_data_directory();
   if (np_error != NPERR_NO_ERROR)
     {
-      PLUGIN_ERROR("Unable create data directory %s\n");
+      PLUGIN_ERROR("Unable to create data directory %s\n", data_directory.c_str());
       return np_error;
     }
     
