@@ -123,39 +123,39 @@ string  user_properties_file(){
 	return string(mypasswd->pw_dir)+"/.config/icedtea-web/"+default_file_ITW_deploy_props_name;
 }
 
-string  get_log_dir(){
+string get_log_dir(){
 	string value;
 	if (!read_deploy_property_value("deployment.user.logdir", value)) {
-		int myuid = getuid();
-		struct passwd *mypasswd = getpwuid(myuid);
-		// try pre 1.5  file location
+		string config_dir;
 		if (getenv ("XDG_CONFIG_HOME") != NULL){
-			string r1= string(getenv ("XDG_CONFIG_HOME"))+"/icedtea-web";
-			string r2 = r1+"/"+default_itw_log_dir_name;
-			if (!IcedTeaPluginUtilities::file_exists(r1)){
-				g_mkdir(r1.c_str(), 755);
-			}
-			if (!IcedTeaPluginUtilities::file_exists(r2)){
-				g_mkdir(r2.c_str(), 755);
-			}
-			return r2;
+			config_dir = string(getenv("XDG_CONFIG_HOME"));
+		} else {
+			int myuid = getuid();
+			struct passwd *mypasswd = getpwuid(myuid);
+			config_dir = string(mypasswd->pw_dir) + "/.config";
 		}
-		//if not then use default
-		string r1 = string(mypasswd->pw_dir)+"/.config/icedtea-web";
-		string r2 = r1+"/"+default_itw_log_dir_name;
-		if (!IcedTeaPluginUtilities::file_exists(r1)){
-			g_mkdir(r1.c_str(), 755);
-		}
-		if (!IcedTeaPluginUtilities::file_exists(r2)){
-			g_mkdir(r2.c_str(), 755);
-		}
-		return r2;
+		string itw_dir = config_dir+"/icedtea-web";
+		string log_dir = itw_dir+"/"+default_itw_log_dir_name;
+		mkdir_checked(itw_dir);
+		mkdir_checked(log_dir);
+		return log_dir;
 	}
 	return value;
 }
 
+void mkdir_checked(string dir){
+	if (!IcedTeaPluginUtilities::file_exists(dir))
+	{
+		const int PERMISSIONS_MASK = S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH; // 0755
+		int stat = g_mkdir(dir.c_str(), PERMISSIONS_MASK);
+		if (stat != 0)
+		{
+			PLUGIN_DEBUG("WARNING: Creation of directory %s failed: %s\n", dir.c_str(), strerror(errno));
+		}
+	}
+}
 
-string  main_properties_file(){
+string main_properties_file(){
 	return "/etc/.java/deployment/"+default_file_ITW_deploy_props_name;
 }
 
